@@ -1,19 +1,21 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of intbitset.
-# Copyright (C) 2007, 2008, 2009, 2010, 2011, 2013, 2014, 2015 CERN.
+# Copyright (C) 2007, 2008, 2009, 2010, 2011, 2013, 2014, 2015, 2016 CERN.
+#
+# SPDX-License-Indetifier: LGPL-3.0-or-later
 #
 # intbitset is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; either version 2 of the
+# modify it under the terms of the GNU Lesser General Public License as
+# published by the Free Software Foundation; either version 3 of the
 # License, or (at your option) any later version.
 #
 # intbitset is distributed in the hope that it will be useful, but
 # WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# General Public License for more details.
+# Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
+# You should have received a copy of the GNU Lesser General Public License
 # along with intbitset; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 
@@ -22,12 +24,14 @@
 __revision__ = "$Id$"
 
 
-import sys
-import zlib
-import six
 import re
-import pkg_resources
+import sys
 import unittest
+import zlib
+
+import pkg_resources
+import six
+
 
 class IntbitsetTest(unittest.TestCase):
     """Test functions related to intbitset data structure."""
@@ -439,6 +443,17 @@ class IntbitsetTest(unittest.TestCase):
             self.assertEqual(intbitset1, intbitset2)
             self.assertEqual(intbitset1, intbitset3)
 
+    def test_set_isdisjoint(self):
+        """intbitset - isdisjoint"""
+        sets = [self.intbitset(set([1, 2])),
+                self.intbitset(set([3, 4])),
+                self.intbitset(set([2, 3]))]
+
+        for set1 in sets:
+            for set2 in sets:
+                if set1 is not set2:
+                    self.assertIs(set1.isdisjoint(set2), set(set1).isdisjoint(set(set2)))
+
     def test_set_pop(self):
         """intbitset - set pop"""
         for set1 in self.sets + [[]]:
@@ -543,3 +558,7 @@ class IntbitsetTest(unittest.TestCase):
             self.assertEqual(intbitset1, intbitset3)
             self.assertEqual(intbitset2.fastdump(), dumped_trails)
             self.assertEqual(intbitset2, intbitset4)
+
+    def test_empty_generator(self):
+        self.intbitset(range(0))
+        self.intbitset(i for i in range(0))
